==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-progressbar/xl-react-widget-progressbar.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {ProgressBar} from 'react-bootstrap';

import classNames from 'classnames';

import './xl-react-widget-progressbar.less';

const STATUSES = {
    error: 'danger',
    progress: 'info',
    success: 'success'
};

export class XlReactWidgetProgressbar extends PureComponent {
    static propTypes = {
        currentStatus: PropTypes.oneOf(['progress', 'success', 'error']),
        disabled: PropTypes.bool,
        handleCancel: PropTypes.func,
        handleClose: PropTypes.func,
        maxValue: PropTypes.number,
        minValue: PropTypes.number,
        model: PropTypes.number,
        stripped: PropTypes.bool
    };

    static defaultProps = {
        currentStatus: 'progress',
        maxValue: 100,
        minValue: 0,
        model: 0
    };

    displayButtonByStatus=(expectedStatus) => this.isCancelable() && this.props.currentStatus === expectedStatus;

    isCancelable=() => Boolean(this.props.handleCancel);

    render() {
        const componentClass = classNames(
            'xl-react-components',
            'xl-react-widget-progressbar',
            {'with-cancel-button': this.isCancelable()}
        );

        const showInProgress = () => this.displayButtonByStatus('progress') ?
            <div
                className="xl-icon-container xl-icon-cancel"
                onClick={this.props.handleCancel}
            /> : null;

        const showSuccess = () => this.displayButtonByStatus('success') ?
            <div
                className="xl-icon-container xl-icon-cancel"
                onClick={this.props.handleClose}
            /> : null;

        const showError = () => this.displayButtonByStatus('error') ?
            <div
                className="xl-icon-container xl-icon-cancel"
                onClick={this.props.handleClose}
            /> : null;

        return (
            <div className={componentClass}>
                <ProgressBar
                    active={this.props.stripped}
                    bsStyle={STATUSES[this.props.currentStatus]}
                    max={this.props.maxValue}
                    min={this.props.minValue}
                    now={this.props.model}
                    striped={this.props.stripped}
                />
                {showInProgress()}
                {showSuccess()}
                {showError()}
            </div>
        );
    }
}

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-progressbar/xl-react-widget-progressbar.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {ProgressBar} from 'react-bootstrap';

import classNames from 'classnames';

import './xl-react-widget-progressbar.less';

const STATUSES = {
    error: 'danger',
    progress: 'info',
    success: 'success'
};

export class XlReactWidgetProgressbar extends PureComponent {
    static propTypes = {
        currentStatus: PropTypes.oneOf(['progress', 'success', 'error']),
        disabled: PropTypes.bool,
        handleCancel: PropTypes.func,
        handleClose: PropTypes.func,
        maxValue: PropTypes.number,
        minValue: PropTypes.number,
        model: PropTypes.number,
        stripped: PropTypes.bool
    };

    static defaultProps = {
        currentStatus: 'progress',
        maxValue: 100,
        minValue: 0,
        model: 0
    };

    displayButtonByStatus=(expectedStatus) => this.isCancelable() && this.props.currentStatus === expectedStatus;

    isCancelable=() => Boolean(this.props.handleCancel);

    render() {
        const componentClass = classNames(
            'xl-react-components',
            'xl-react-widget-progressbar',
            {'with-cancel-button': this.isCancelable()}
        );

        const showInProgress = () => this.displayButtonByStatus('progress') ?
            <div
                className="xl-icon close-icon"
                onClick={this.props.handleCancel}
            /> : null;

        const showSuccess = () => this.displayButtonByStatus('success') ?
            <div
                className="xl-icon close-icon"
                onClick={this.props.handleClose}
            /> : null;

        const showError = () => this.displayButtonByStatus('error') ?
            <div
                className="xl-icon close-icon"
                onClick={this.props.handleClose}
            /> : null;

        return (
            <div className={componentClass}>
                <ProgressBar
                    active={this.props.stripped}
                    bsStyle={STATUSES[this.props.currentStatus]}
                    max={this.props.maxValue}
                    min={this.props.minValue}
                    now={this.props.model}
                    striped={this.props.stripped}
                />
                {showInProgress()}
                {showSuccess()}
                {showError()}
            </div>
        );
    }
}
